package com.ruoyi.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.SysPointControl;

/**
 * 积分控制Mapper接口
 *
 * @author ruoyi
 * @date 2025-05-28
 */
public interface SysPointControlMapper extends BaseMapper<SysPointControl>
{
    /**
     * 查询积分控制
     *
     * @param id 积分控制主键
     * @return 积分控制
     */
    public SysPointControl selectSysReviewControlById(Long id);

    /**
     * 查询积分控制列表
     *
     * @param sysReviewControl 积分控制
     * @return 积分控制集合
     */
    public List<SysPointControl> selectSysReviewControlList(SysPointControl sysReviewControl);

    /**
     * 新增积分控制
     *
     * @param sysReviewControl 积分控制
     * @return 结果
     */
    public int insertSysReviewControl(SysPointControl sysReviewControl);

    /**
     * 修改积分控制
     *
     * @param sysReviewControl 积分控制
     * @return 结果
     */
    public int updateSysReviewControl(SysPointControl sysReviewControl);

    /**
     * 删除积分控制
     *
     * @param id 积分控制主键
     * @return 结果
     */
    public int deleteSysReviewControlById(Long id);

    /**
     * 批量删除积分控制
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysReviewControlByIds(Long[] ids);
}
