package com.ruoyi.web.controller.system;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysPointControl;
import com.ruoyi.system.service.ISysPointControlService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 积分控制Controller
 *
 * @author ruoyi
 * @date 2025-05-28
 */
@RestController
@RequestMapping("/system/pointcontrol")
public class SysPointControlController extends BaseController
{
    @Autowired
    private ISysPointControlService sysReviewControlService;

    /**
     * 查询积分控制列表
     */
    @PreAuthorize("@ss.hasPermi('system:pointcontrol:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysPointControl sysReviewControl)
    {
        startPage();
        List<SysPointControl> list = sysReviewControlService.selectSysReviewControlList(sysReviewControl);
        return getDataTable(list);
    }

    /**
     * 导出积分控制列表
     */
    @PreAuthorize("@ss.hasPermi('system:pointcontrol:export')")
    @Log(title = "积分控制", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysPointControl sysReviewControl)
    {
        List<SysPointControl> list = sysReviewControlService.selectSysReviewControlList(sysReviewControl);
        ExcelUtil<SysPointControl> util = new ExcelUtil<SysPointControl>(SysPointControl.class);
        util.exportExcel(response, list, "积分控制数据");
    }

    /**
     * 获取积分控制详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:pointcontrol:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sysReviewControlService.selectSysReviewControlById(id));
    }

    /**
     * 新增积分控制
     */
    @PreAuthorize("@ss.hasPermi('system:pointcontrol:add')")
    @Log(title = "积分控制", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysPointControl sysReviewControl)
    {
        return toAjax(sysReviewControlService.insertSysReviewControl(sysReviewControl));
    }

    /**
     * 修改积分控制
     */
    @PreAuthorize("@ss.hasPermi('system:pointcontrol:edit')")
    @Log(title = "积分控制", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysPointControl sysReviewControl)
    {
        return toAjax(sysReviewControlService.updateSysReviewControl(sysReviewControl));
    }

    /**
     * 删除积分控制
     */
    @PreAuthorize("@ss.hasPermi('system:pointcontrol:remove')")
    @Log(title = "积分控制", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysReviewControlService.deleteSysReviewControlByIds(ids));
    }
}
